Crate android_auto

Crate android_auto 

This crate provides android auto functionality for devices wishing to comunicate using the android auto protocol.

Re-exports

pub use protobuf;

Modules

Bluetooth
Generated file from Bluetooth.proto
Wifi
Generated file from Wifi.proto

Structs

AndroidAutoConfiguration
Provides basic configuration elements for setting up an android auto head unit
AndroidAutoSetup
Token proving that setup has been called. Required to use the library’s main entry points so that initialisation cannot be forgotten.
BluetoothInformation
The required bluetooth information
HeadUnitInfo
Information about the head unit that will be providing android auto services for compatible devices
InputConfiguration
The configuration for an input channel
NetworkInformation
The wireless network information to relay to the compatible android auto device
SendableAndroidAutoMessage
The sendable form of an AndroidAutoMessage
SensorInformation
The sensor information supported by the user for android auto
VideoConfiguration
The configuration data for the video stream of android auto

Enums

AndroidAutoChannelMessageFromApp
A message sent from an app user to this crate
AndroidAutoMessage
The types of messages that can be sent over the android auto link
AudioChannelType
The types of audio channels that can exist
ClientError
Errors that can occur during communication with a client
ConnectionType
The types of connections that can exist, exists to make it possible for the usb and wireless features to work with tokio::select macro
FrameHeaderType
Specifies the type of frame header, whether the data of a packet is contained in a single frame, or if it was too large and broken up into multiple frames for transmission.
FrameIoError
Errors that can occur when either sending or receiving frames
FrameReceiptError
Errors that can occur when trying to receive frames
FrameSequenceError
A sequence error in frames received
FrameTransmissionError
An error that can occur when transmitting a frame
SendableChannelType
The type of channel being sent in a sendable message
SslHandshakeError
Errors that can occur during the handshake process

Traits

AndroidAutoAudioInputTrait
This trait is implemented by users that have audio input capabilities
AndroidAutoAudioOutputTrait
This trait is implemented by users that have audio output capabilities
AndroidAutoBluetoothTrait
A trait that is implemented for users that somehow support bluetooth for their hardware
AndroidAutoInputChannelTrait
This trait is implemented by users that have inputs for their head unit
AndroidAutoMainTrait
The base trait for crate users to implement
AndroidAutoNavigationTrait
This trait is implemented by users that support navigation indicators
AndroidAutoSensorTrait
This trait is implemented by users that support navigation indicators
AndroidAutoVideoChannelTrait
This trait is implemented by users wishing to display a video stream from an android auto (phone probably).
AndroidAutoWiredTrait
this trait is implemented by users that support wired (usb) android auto

Functions

setup
Perform any setup required on startup of the library.