pub enum AndroidAutoMessage {
Input(InputEventIndication),
Audio(Option<u64>, Vec<u8>),
Sensor(SensorEventIndication),
Other,
}Expand description
The types of messages that can be sent over the android auto link
Variants
Input(InputEventIndication)
An input message
Audio(Option<u64>, Vec<u8>)
An audio packet message, optional timestamp (microseconds since UNIX_EPOCH) and data
Sensor(SensorEventIndication)
A sensor event message
Other
An other message
Implementations
Sourceimpl AndroidAutoMessage
impl AndroidAutoMessage
Sourcepub fn sendable(self) -> SendableAndroidAutoMessage
pub fn sendable(self) -> SendableAndroidAutoMessage
Convert the message to something that can be sent, if possible