pub enum ClientError {
InvalidRootCert,
InvalidClientCertificate,
InvalidClientPrivateKey,
IoError(FrameIoError),
}Expand description
Errors that can occur during communication with a client
Variants
InvalidRootCert
The root certificate for the ssl communications was invalid
InvalidClientCertificate
The client certificate was invalid
InvalidClientPrivateKey
The client private key was invalid
IoError(FrameIoError)
A communication error