pub enum ConnectionType {
Usb(AndroidAutoUsb),
}Expand description
The types of connections that can exist, exists to make it possible for the usb and wireless features to work with tokio::select macro
Variants
Usb(AndroidAutoUsb)
The variant for usb connections