pub enum FrameIoError {
Rx(FrameReceiptError),
Tx(FrameTransmissionError),
ShutdownRequested,
IncompatibleVersion(u16, u16),
SslHandshake(SslHandshakeError),
Sequence(FrameSequenceError),
AudioInputOpenError,
AudioInputCloseError,
}Expand description
Errors that can occur when either sending or receiving frames
Variants
Rx(FrameReceiptError)
An error receiving a frame
Tx(FrameTransmissionError)
An error sending a frame
ShutdownRequested
A shutdown was requested
IncompatibleVersion(u16, u16)
The client has an incompatible version
SslHandshake(SslHandshakeError)
An error occurred during the ssl handshake
Sequence(FrameSequenceError)
A logical error due to frames not being received in the expected order
AudioInputOpenError
An error occurred opening the audio input channel
AudioInputCloseError
An error occurred closing the audio input channel