pub enum FrameReceiptError {
TimeoutHeader,
Disconnected,
UnexpectedDuringFrameChannel(Error),
UnexpectedDuringFrameHeader(Error),
UnexpectedDuringFrameLength(Error),
UnexpectedDuringFrameContents(Error),
TlsReadError(Error),
TlsProcessingError(Error),
}Expand description
Errors that can occur when trying to receive frames
Variants
TimeoutHeader
A timeout occurred when trying to receive the frame header
Disconnected
The connection was disconnected
UnexpectedDuringFrameChannel(Error)
An unexpected error receiving the frame channel id
UnexpectedDuringFrameHeader(Error)
An unexpected error receiving the frame header
UnexpectedDuringFrameLength(Error)
An unexpected error receiving the frame length
UnexpectedDuringFrameContents(Error)
An unexpected error receiving the frame contents
TlsReadError(Error)
An error occurred calling read_tls with the received frame payload
TlsProcessingError(Error)
An error occurred processing tls data received