setup

Function setup 

pub fn setup() -> AndroidAutoSetup
Perform any setup required on startup of the library.

Returns an AndroidAutoSetup token that must be passed to AndroidAutoMainTrait::run (and related methods). Requiring this token at the call site ensures that setup is never accidentally skipped.