pub struct AndroidAutoConfiguration {
pub unit: HeadUnitInfo,
pub custom_certificate: Option<(Vec<u8>, Vec<u8>)>,
}Expand description
Provides basic configuration elements for setting up an android auto head unit
Fields
unit: HeadUnitInfoThe head unit information
custom_certificate: Option<(Vec<u8>, Vec<u8>)>The android auto client certificate and private key in pem format (only if a custom one is desired)