AndroidAutoAudioOutputTrait

Trait AndroidAutoAudioOutputTrait 

pub trait AndroidAutoAudioOutputTrait {
    // Required methods
    fn open_output_channel<'life0, 'async_trait>(
        &'life0 self,
        t: AudioChannelType,
    ) -> Pin<Box<dyn Future<Output = Result<(), ()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn close_output_channel<'life0, 'async_trait>(
        &'life0 self,
        t: AudioChannelType,
    ) -> Pin<Box<dyn Future<Output = Result<(), ()>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn receive_output_audio<'life0, 'async_trait>(
        &'life0 self,
        t: AudioChannelType,
        data: Vec<u8>,
    ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn start_output_audio<'life0, 'async_trait>(
        &'life0 self,
        t: AudioChannelType,
    ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn stop_output_audio<'life0, 'async_trait>(
        &'life0 self,
        t: AudioChannelType,
    ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
This trait is implemented by users that have audio output capabilities

Required Methods

fn open_output_channel<'life0, 'async_trait>( &'life0 self, t: AudioChannelType, ) -> Pin<Box<dyn Future<Output = Result<(), ()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Opens the specified channel

fn close_output_channel<'life0, 'async_trait>( &'life0 self, t: AudioChannelType, ) -> Pin<Box<dyn Future<Output = Result<(), ()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Closes the specified channel

fn receive_output_audio<'life0, 'async_trait>( &'life0 self, t: AudioChannelType, data: Vec<u8>, ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Receive a chunk of audio data for the specified channel

fn start_output_audio<'life0, 'async_trait>( &'life0 self, t: AudioChannelType, ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

The specified audio channel will start

fn stop_output_audio<'life0, 'async_trait>( &'life0 self, t: AudioChannelType, ) -> Pin<Box<dyn Future<Output = ()> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

The specified audio channel will stop

Implementors