pub trait AndroidAutoInputChannelTrait {
// Required methods
fn binding_request<'life0, 'async_trait>(
&'life0 self,
code: u32,
) -> Pin<Box<dyn Future<Output = Result<(), ()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn retrieve_input_configuration(&self) -> &InputConfiguration;
}Expand description
This trait is implemented by users that have inputs for their head unit
Required Methods
Sourcefn binding_request<'life0, 'async_trait>(
&'life0 self,
code: u32,
) -> Pin<Box<dyn Future<Output = Result<(), ()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn binding_request<'life0, 'async_trait>(
&'life0 self,
code: u32,
) -> Pin<Box<dyn Future<Output = Result<(), ()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
A binding request for the specified keycode, generally the same code reported in AndroidAutoConfig::keycodes_supported
Sourcefn retrieve_input_configuration(&self) -> &InputConfiguration
fn retrieve_input_configuration(&self) -> &InputConfiguration
Retrieve the input configuration