This crate provides android auto functionality for devices wishing to comunicate using the android auto protocol.
Re-exports
pub use protobuf;
Modules
Structs
- Android
Auto Configuration - Provides basic configuration elements for setting up an android auto head unit
- Android
Auto Setup - Token proving that
setuphas been called. Required to use the library’s main entry points so that initialisation cannot be forgotten. - Bluetooth
Information - The required bluetooth information
- Head
Unit Info - Information about the head unit that will be providing android auto services for compatible devices
- Input
Configuration - The configuration for an input channel
- Network
Information - The wireless network information to relay to the compatible android auto device
- Sendable
Android Auto Message - The sendable form of an
AndroidAutoMessage - Sensor
Information - The sensor information supported by the user for android auto
- Video
Configuration - The configuration data for the video stream of android auto
Enums
- Android
Auto Channel Message From App - A message sent from an app user to this crate
- Android
Auto Message - The types of messages that can be sent over the android auto link
- Audio
Channel Type - The types of audio channels that can exist
- Client
Error - Errors that can occur during communication with a client
- Connection
Type - The types of connections that can exist, exists to make it possible for the usb and wireless features to work with tokio::select macro
- Frame
Header Type - Specifies the type of frame header, whether the data of a packet is contained in a single frame, or if it was too large and broken up into multiple frames for transmission.
- Frame
IoError - Errors that can occur when either sending or receiving frames
- Frame
Receipt Error - Errors that can occur when trying to receive frames
- Frame
Sequence Error - A sequence error in frames received
- Frame
Transmission Error - An error that can occur when transmitting a frame
- Sendable
Channel Type - The type of channel being sent in a sendable message
- SslHandshake
Error - Errors that can occur during the handshake process
Traits
- Android
Auto Audio Input Trait - This trait is implemented by users that have audio input capabilities
- Android
Auto Audio Output Trait - This trait is implemented by users that have audio output capabilities
- Android
Auto Bluetooth Trait - A trait that is implemented for users that somehow support bluetooth for their hardware
- Android
Auto Input Channel Trait - This trait is implemented by users that have inputs for their head unit
- Android
Auto Main Trait - The base trait for crate users to implement
- Android
Auto Navigation Trait - This trait is implemented by users that support navigation indicators
- Android
Auto Sensor Trait - This trait is implemented by users that support navigation indicators
- Android
Auto Video Channel Trait - This trait is implemented by users wishing to display a video stream from an android auto (phone probably).
- Android
Auto Wired Trait - this trait is implemented by users that support wired (usb) android auto
Functions
- setup
- Perform any setup required on startup of the library.